#
# spec file for package python-fastremap
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
%define         skip_python36 1
Name:           python-fastremap
Version:        1.14.0
Release:        1.3
Summary:        Module to Remap, mask, renumber, and in-place transpose numpy arrays
License:        LGPL-3.0-only
URL:            https://github.com/seung-lab/fastremap/
Source:         https://files.pythonhosted.org/packages/source/f/fastremap/fastremap-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel >= 1.16.0}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.16.0
%python_subpackages

%description
A module to remap, mask, renumber, and in-place transpose numpy arrays.

%prep
%setup -q -n fastremap-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%doc AUTHORS ChangeLog README.md
%license LICENSE
%{python_sitearch}/*

%changelog
* Tue Dec  5 2023 Dirk Müller <dmueller@suse.com>
- update to 1.14.0:
  * docs: add README info and docstring
  * docs: add tobytes example
  * feat: bulk tobytes
* Thu May 18 2023 Dirk Müller <dmueller@suse.com>
- update to 1.13.5:
  * release(1.13.5): updated build for py311
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.13.4:
  * release(1.13.4): easier installation
  * Delayed numpy import during setup
  * fix: handle all LP64 platforms generically
* Sun Jan  8 2023 Dirk Müller <dmueller@suse.com>
- update to 1.13.3:
  * release(1.13.2): (inverse\_)component\_map accepts non-aligned inputs
  * fix: component\_map and inverse\_component\_map accept non-aligned
    inputs
  * fixtest: elements in inv\_component\_map are now sorted
  * feat: unique accepts lists
  * fix: remove duplicates from inverse\_component\_map
  * build: update build system with aarch64 and py310
  * release(1.13.0): using improved map for faster renumber, remap, more
  * perf: switch to ska::flat\_hash\_map instead of std::unordered\_map
  * release(1.12.2): release binaries with broader numpy ABI compat
  * chore: use oldest-supported-numpy when building wheels
  * release(1.12.1): unique accepts empty arrays
  * fix: fastremap.unique doesn't accept empty arrays
  * release(1.12.0): new point\_cloud and foreground functions
  * feat(point\_cloud): new point\_cloud and foreground functions
  * fix(renumber): preserve\_zero=False w/ arrays starting with 0
* Thu Apr 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.11.4:
  * chore: support only py36 - py39
  * chore: drop py27 from build
  * fix(inverse\_component\_map): not checking component for continue cond
  * release(1.11.2): fix numpy deprecation of np.bool
  * fix: further fix numpy deprecation of np.bool
  * chore: fix numpy 1.20 deprecation of np.bool in favor of bool
  * chore: update setup.cfg
  * release(1.11.1): python39 support
  * chore: make build\_linux.sh script generic
  * chore: add updated build system
  * fix: pbr couldn't see git repo
  * release(1.11.0): unique(..., return\_index=True) now accelerated
  * feat(unique): adds return\_index to high performance paths (#25)
- Do not build on Python 3.6, due to no NumPy.
* Thu Jul  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 1.10.2
  * release(1.10.2): fixed bug in remap
  * fix: remap was not handling missing labels correctly (#23)
  * Revert "feat: adds argminmax, argmin, argmax, ravel\_index (#22)"
  * feat: adds argminmax, argmin, argmax, ravel\_index (#22)
  * chore: update changelog
  * chore: adds tox
  * release(1.10.1): faster renumber and by proxy unique in some circumstances
  * chore: add tox.ini
  * perf: faster renumber by using unordered\_map (#21)
  * release(1.10.0): adds component\_map and inverse\_component\_map
  * fix: should use int instead of uint
  * test: abort appveyor early if a test fails
  * fix: test for renumber dying on uint64 assertion
  * fix: remove 'build.cmd' as we are not supporting 3.3 or 3.4
  * chore: add appveyor.yml
  * docs: show how to use component\_map and inverse\_component\_map
  * feat: add components\_map and inverse\_components\_map
  * Update README.md
  * release(1.9.2): fixed performance issue with fastremap.unique
  * perf: faster unique\_va\_array
  * release(1.9.1): ipt handles 64-bit addressable arrays
  * fix: support 64-bit addressable volumes for IPT
  * release(1.9.0): adds unique, minmax, refit, fit\_dtype, pixel\_pairs
  * chore: add py3.8 to dockerfile
  * feat: unique, minmax, refit, fit\_dtype, pixel\_pairs (#20)
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to version 1.8.0
  * faster remap and mask operators
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- Update to version 1.7.0
  * feat: add support for single precision complex numbers to IPT
  * docs: move "all available functions" higher
* Tue Sep 17 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Mon Sep 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.6.2
